@@ -15,8 +15,7 @@ from . import glob_colors as colors
 # Get screen info, remove toolbar
 # matplotlib.rcParams['toolbar'] = 'None'
 matplotlib.rcParams['backend'] = 'GTK3Agg'
-matplotlib.rcParams['pcolor.shading'] = 'auto'
-matplotlib.rc('text', usetex=True)
+# matplotlib.rcParams['pcolor.shading'] = 'auto'
 # matplotlib.rcParams['text.latex.preamble']=[r"\usepackage{amsmath}"]
 noscreen=False
 try:
@@ -39,21 +38,35 @@ except:
     print('using screenszie=[20.0,11.25] inches')
     screen_size=np.array([20.  , 11.25])
     noscreen=True
+#test if usetex=True works(pain in the ... this usetex)
+matplotlib.rc('text', usetex=False)
+# if not plt.isinteractive():
+#     try:
+#         matplotlib.rc('text', usetex=True)
+#         fig,ax = plt.subplots()
+#         ax.set_title('testing $\AA^{-1}$')
+#         fig.canvas.draw()
+#         plt.close()
+#     except:
+#         matplotlib.rc('text', usetex=False)
+#         print('warning setting usetex=False')
+markers = list(matplotlib.markers.MarkerStyle.markers.keys())[2:-5]
 
 ###########################################################################
 #def : plotting standard
 ###########################################################################
-def standardDisplay(ax,labs=['','',''],name='', xylims=[], axPos=1,legOpt=None,view=None,
+def standardDisplay(ax,labs=['','',''],figname=None,name='', xylims=[], axPos=1,legOpt=None,view=None,
     fonts=[30,25,15,20], c=['k','k'], logOpt='',changeXYlims=True,is_3d=0,
     gridOn=True,gridmOn=False,ticksOn=True,title='',legLoc='best',legElt=[],
     figopt='1',xyTicks=None,xyTicksm=None,xyTickLabs=None,mg=0.05,opt='p',setPos=True,equal=False,
-    pOpt=None):
+    pOpt=None,bgcol=None):
     '''
     legElt : dict - {'lab1':[(1,0,0),'s-']} overrides existing handles
     opt : p(plot), s(save), c(close) '
     pOpt : p(setPos)X(changeXYlims)l(legOpt)t(ticksOn)e(equal),G(gridOn),g(gridmOn)
     view : [elev,azim] for 3D projection axes
     '''
+    if figname:name=figname
     is_3d = "3D" in str(ax.__class__)
     if isinstance(pOpt,str):
         setPos,changeXYlims,legOpt,ticksOn,equal,gridOn,gridmOn = [s in pOpt for s in 'pXlteGg']
@@ -70,6 +83,7 @@ def standardDisplay(ax,labs=['','',''],name='', xylims=[], axPos=1,legOpt=None,v
     ax.axis(['off','on'][ticksOn])
     ax.set_axisbelow(True)
     if setPos : ax.set_position(axPos);
+    if bgcol:ax.set_facecolor(bgcol)
     #lims,ticks and grid
     xylims=changeAxesLim(ax,mg,xylims,is_3d,changeXYlims)#;print(changeXYlims,xylims)
     change_ticks(ax,xyTicks,xyTickLabs,xylims,is_3d,xyTicksm)
@@ -91,7 +105,7 @@ def standardDisplay(ax,labs=['','',''],name='', xylims=[], axPos=1,legOpt=None,v
 def stddisp(plots=[],scat=None,texts=[],colls=[],patches=[],im=None,rot=0,
             tricont=None,contour=None,quiv=None,surfs=[],caxis=None,
             cs=None,lw=1,ms=5,marker='o',fonts={},axPos=1,imOpt='',cb_pos=[],cmap='jet',
-            ax=None,fig=None,cb=None,figsize=(0.5,1),pad=None,rc='11',
+            ax=None,fig=None,cb=None,figsize=[0.5,1],pad=None,rc='11',
             inset=None,iOpt='Gt',name='',opt='p',figopt='',pargs={},arrows=[],
             std=1,sargs={},pOpt=None,**kwargs):
     '''
@@ -103,6 +117,7 @@ def stddisp(plots=[],scat=None,texts=[],colls=[],patches=[],im=None,rot=0,
     imOpt   : c(colorbar) h(horizontal) v(vertical)
     cs      : C(contours),I(image),S(scatter),N(None) artist to use for colorbar
     iOpt    : inset displayStandards keys - ['axpos','xylims','ms','lw','lwp']
+    pOpt    : 'im' default for plotting an image with colorbar etc...
     kwargs  : standardDisplay
     '''
     if isinstance(fonts,dict) or isinstance(fonts,str): fonts = get_font(fonts)
@@ -111,19 +126,22 @@ def stddisp(plots=[],scat=None,texts=[],colls=[],patches=[],im=None,rot=0,
     if ax and not axPos : axPos=ax.get_position().bounds
     #add lines,patches,texts,scatters
     is_3d = "3D" in str(ax.__class__) # not isinstance(ax,matplotlib.axes._subplots.Subplot) and not isinstance(ax,matplotlib.axes._axes.Axes)#;print(is_3d)
-    for coll in colls : ax.add_collection(coll)
-    for pp in patches : ax.add_patch(pp)
-    pltPlots(ax,plots,lw,ms,is_3d,pargs)
-    pltTexts(ax,texts,fsT,is_3d)
-    pltArrows(ax,arrows)
-    if pOpt=='im':pOpt,imOpt,axPos,cs = 'pt', 'c','V','I'
-
     #note that at them moment only one cb per ax authorized
     # priority order here : scat,im,contour
     css = dict(zip(['I','S','C','N'],[None]*4))
     if not contour==None:css['C'] = plt_contours(ax,contour,quiv,cmap,lw)
     if not im==None:css['I']      = pltImages(ax,im,cmap,caxis,imOpt,rot)
     if not scat==None:css['S']    = pltScat(ax,scat,c='b',s=ms,marker=marker,proj_3D=rc=='3d',cmap=cmap,caxis=caxis,sargs=sargs)
+
+    for coll in colls : ax.add_collection(coll)
+    for pp in patches : ax.add_patch(pp)
+    pltPlots(ax,plots,lw,ms,is_3d,pargs)
+    pltTexts(ax,texts,fsT,is_3d)
+    pltArrows(ax,arrows)
+    if pOpt=='im':
+        pOpt,imOpt,axPos = 'pt', 'c','V'
+        if 'xylims' in kwargs.keys():pOpt+='X'
+
     # if 'c' in imOpt and contour==None and scat==None and im==None:cs=None
     if isinstance(cs,str) : cs=css[cs]
     add_colorbar(fig,ax,cs,cb,imOpt,cmap,is_3d,caxis=caxis,cb_pos=cb_pos)
@@ -313,7 +331,7 @@ def pltTexts(ax,texts,fsT,is_3d=0):
     else:
         for t in texts:
             c_t = 'k' if len(t)<4 else t[3]
-            ax.text(t[0],t[1],t[2],fontsize=fsT,color=c_t)
+            ax.text(t[0],t[1],t[2],fontsize=fsT,color=c_t,horizontalalignment='center')
 def pltImages(ax,im=None,cmap='viridis',caxis=None,imOpt='',rot=0):
     cs = None
     if isinstance(im,str):
@@ -347,19 +365,28 @@ def pltImages(ax,im=None,cmap='viridis',caxis=None,imOpt='',rot=0):
             cs=ax.imshow(im[0],cmap=cmap,**args)
     return cs
 
-def pltScat(ax,scat,**kwargs):
+def pltScat(ax,scat,sargs={},**kwargs):
     cs = None
     if len(scat):
         if isinstance(scat,tuple):
             for scat0 in scat:
+                # if len(scat0)>5:
+                #     kwargs['cmap']=scat0[-1]
+                #     # print('cmap',kwargs['cmap'])
+                #     scat0=scat0[:-1]
+                if type(scat0[-1])==dict:
+                    sargs = scat0[-1]
+                    scat0=scat0[:-1]
+                    kwargs['caxis'] = None
+                    # kwargs['cmap'] = None
                 kwargs['marker']=scat0[-1]
                 scat0=scat0[:-1]
-                cs = pltScatter(ax,scat=scat0,**kwargs)
+                cs = pltScatter(ax,scat=scat0,sargs=sargs,**kwargs)
         else:
             cs = pltScatter(ax,scat,**kwargs)
     return cs
 
-def pltScatter(ax,scat,c='b',s=5,marker='o',proj_3D=False,cmap='jet',caxis=None,sargs={}) :
+def pltScatter(ax,scat,c='b',s=5,marker='o',proj_3D=False,cmap=None,caxis=None,sargs={}) :
     '''
     - scat : [x,y,<z>,s,c] or [x,y,<z>,c]
     - s : int or list/np.array of int
@@ -379,8 +406,8 @@ def pltScatter(ax,scat,c='b',s=5,marker='o',proj_3D=False,cmap='jet',caxis=None,
     if proj_3D :
         cs=ax.scatter3D(x,y,z,s=s,c=c,marker=marker,cmap=cmap)
     else :
-        if caxis : sargs.update({'vmin':caxis[0],'vmax':caxis[1]})
-        cs=ax.scatter(x,y,s,c,marker=marker,cmap=cmap,**sargs)
+        if caxis : sargs.update({'cmap':cmap,'vmin':caxis[0],'vmax':caxis[1]})
+        cs=ax.scatter(x,y,s,c,marker=marker,**sargs)
     return cs
 
 def pltSurfs(ax,surfs,c='b',a=0.2,lw=1,ec='b'):
@@ -409,17 +436,24 @@ def plt_contours(ax,contour,quiv,cmap,lw):
 ########################################################################
 # handles and properties
 ########################################################################
-def create_fig(figsize=(0.5,1),pad=None,rc='11') :
+def create_fig(figsize=[0.5,1],pad=None,rc='11') :
     '''figsize :
-        tuple : (width,height) normalized units
+        tuple : (width,height) inches
+        list  : (width,height) normalized units
         str   : f(full),12(half),22(quarter)
         rc    : str or list - layout arrangement : '3d','11','22',...
     '''
-    if isinstance(figsize,str) :
-        figsize = {'f':(1,1),'12':(0.5,1),'21':(1,0.5),'22':(0.5,0.5)}[figsize]
+    # print(type(figsize))
     if isinstance(rc,str) :
         rc = {'fig':'fig','3d':'3d','11':[1,1],'21':[2,1],'12':[1,2],'22':[2,2]}[rc];#print(rc)
-    figsize = tuple(np.array(figsize)*screen_size)
+    if isinstance(figsize,str) :
+        figsize = {'f':(1,1),'12':(0.5,1),'21':(1,0.5),'22':(0.5,0.5)}[figsize]
+    elif isinstance(figsize,int) :
+        figsize = (figsize,figsize)
+    elif isinstance(figsize,list) :
+        # print('default')
+        figsize = tuple(np.array(figsize)*screen_size)
+
     if rc=='3d':
         wh = min(screen_size)
         figsize = (wh,wh);#print(figsize)
@@ -554,7 +588,11 @@ def get_lims(ax,mg,xylims=None,is_3d=0):
     return xylims
 
 def changeAxesLim(ax,mg,xylims=[],is_3d=0,changeXYlims=0):
-    if isinstance(xylims,float) or isinstance(xylims,int):xylims=np.array([-1,1,-1,1])*xylims
+    if isinstance(xylims,float) or isinstance(xylims,int):
+        if is_3d:
+            xylims=np.array([-1,1,-1,1,-1,1])*xylims
+        else:
+            xylims=np.array([-1,1,-1,1])*xylims
     if isinstance(xylims,np.ndarray):xylims=xylims.tolist()
     xylims = get_lims(ax,mg,xylims,is_3d)
     if len(xylims)==4:
@@ -673,9 +711,9 @@ def disp_quick(name,ax,opt,figopt):
     if 'p' in opt : ax.figure.show()
     if 'c' in opt : plt.close(ax.figure)
 
-def im2gif(figpattern,fmt='svg'):
+def im2gif(figpattern,fmt='svg',v=1):
     cmd='im2gif '+figpattern +' ' + fmt
-    print(colors.magenta+cmd+'  ...'+colors.black)
+    if v:print(colors.magenta+cmd+colors.black)
     out=check_output(['/bin/bash','-i','-c',cmd]).decode()
     print(colors.green+out+colors.black)
 
